# Maplewood

maplewood is a Python Library for creating logfiles in Plain Text(.txt) Format

## Compatibility
PyLogger has been tested to work on Windows, but should work on Linux and MacOS as well

## Installing